@@ -1,27 +1,23 @@
 <?php
 	class profile_controller extends controller {
 		private function show_profile_form($profile) {
-			global $notification_methods;
-
-			$this->output->add_javascript("md5.js");
+			$this->output->add_javascript("banshee/".PASSWORD_HASH.".js");
 			$this->output->add_javascript("profile.js");
+			$this->output->run_javascript("hash = window['".PASSWORD_HASH."'];");
 
 			$this->output->open_tag("edit");
 
+			$this->output->add_tag("username", $this->user->username);
 			$this->output->add_tag("email", $profile["email"]);
 			$this->output->add_tag("notification_key", $profile["notification_key"]);
 			$this->output->add_tag("notification_method", $profile["notification_method"]);
 			$this->output->add_tag("daily_report", show_boolean($profile["daily_report"]));
 			if ($this->user->status == USER_STATUS_CHANGEPWD) {
 				$this->output->add_tag("cancel", "Logout", array("page" => LOGOUT_MODULE));
+			} else {
+				$this->output->add_tag("cancel", "Back", array("page" => $this->settings->start_page));
 			}
 
-			$this->output->open_tag("notification");
-			foreach ($notification_methods as $method => $label) {
-				$this->output->add_tag("method", $method, array("label" => $label));
-			}
-			$this->output->close_tag();
-
 			/* Action log
 			 */
 			if (($actionlog = $this->model->last_account_logs()) !== false) {
@@ -40,6 +36,10 @@
 			$this->output->keywords = "profile";
 			$this->output->title = "Profile";
 
+			if ($this->user->status == USER_STATUS_CHANGEPWD) {
+				$this->output->add_message("Please, change your password.");
+			}
+
 			if ($_SERVER["REQUEST_METHOD"] == "POST") {
 				/* Update profile
 				 */
@@ -53,6 +53,7 @@
 				}
 			} else {
 				$user = array(
+					"fullname"            => $this->user->fullname,
 					"email"               => $this->user->email,
 					"notification_key"    => $this->user->notification_key,
 					"notification_method" => $this->user->notification_method,
